OC.L10N.register(
    "files",
    {
    "Unknown error" : "不明錯誤",
    "Files" : "文件",
    "All files" : "所有文件",
    "Home" : "主頁",
    "Close" : "關閉",
    "Download" : "下載",
    "Rename" : "重新命名",
    "Delete" : "刪除",
    "Unshare" : "取消分享",
    "Name" : "名稱",
    "Size" : "大小",
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "New" : "新增",
    "Folder" : "資料夾",
    "New folder" : "新資料夾",
    "Upload" : "上戴",
    "A new file or folder has been <strong>created</strong>" : "新檔案或資料夾已被 <strong> 新增 </strong>",
    "A file or folder has been <strong>changed</strong>" : "檔案或資料夾已被 <strong> 變成 </strong>",
    "A file or folder has been <strong>deleted</strong>" : "新檔案或資料夾已被 <strong> 刪除 </strong>",
    "You created %1$s" : "你新增了%1$s",
    "%2$s created %1$s" : "%2$s 新增了 %1$s",
    "You changed %1$s" : "你改變了%1$s",
    "%2$s changed %1$s" : "%2$s 改變了 %1$s",
    "You deleted %1$s" : "你刪除了%1$s",
    "%2$s deleted %1$s" : "%2$s 刪除了 %1$s",
    "Save" : "儲存",
    "Settings" : "設定",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "取消上戴",
    "You changed %1$s" : "你改變了%1$s",
    "You created %1$s" : "你新增了%1$s",
    "You deleted %1$s" : "你刪除了%1$s"
},
"nplurals=1; plural=0;");
